@@ -397,34 +397,34 @@ void DevicePropertiesDialog::populateDeviceInformation() {
 			// Show status
 			TQString status_text = "<qt>";
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Mountable)) {
-				status_text += "Mountable<br>";
+				status_text += i18n("Mountable") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Removable)) {
-				status_text += "Removable<br>";
+				status_text += i18n("Removable") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Inserted)) {
-				status_text += "Inserted<br>";
+				status_text += i18n("Inserted") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Blank)) {
-				status_text += "Blank<br>";
+				status_text += i18n("Blank") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::UsedByDevice)) {
-				status_text += "In use<br>";
+				status_text += i18n("In use") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::UsesDevice)) {
-				status_text += "Uses other device<br>";
+				status_text += i18n("Uses other device") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::ContainsFilesystem)) {
-				status_text += "Contains a filesystem<br>";
+				status_text += i18n("Contains a filesystem") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Hotpluggable)) {
-				status_text += "Hotpluggable<br>";
+				status_text += i18n("Hotpluggable") + "<br>";
 			}
 			if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::Hidden)) {
-				status_text += "Hidden<br>";
+				status_text += i18n("Hidden") + "<br>";
 			}
 			if (status_text == "<qt>") {
-				status_text += "<i>Unavailable</i>";
+				status_text += "<i>" + i18n("Unknown") + "</i>";
 			}
 			status_text += "</qt>";
 			base->labelDiskStatus->setText(status_text);
@@ -637,7 +637,7 @@ void DevicePropertiesDialog::populateDeviceInformation() {
 			}
 
 			// RandR warning
-			base->labelRandrWarning->setText("<qt><b>NOTE: Any further integration of displays into TDE <i>REQUIRES</i> multi GPU support and other features slated for RandR 2.0.</b><p>Development on such features has been sorely lacking for well over a year as of 2012; if you want to see Linux come up to Windows and Macintosh standards in this area <i>please tell the Xorg developers</i> at http://www.x.org/wiki/XorgMailingLists<p>The TDE project badly needs these features before it can proceed with graphical monitor configuration tools:<br> * GPU object support<br> * The ability to query the active driver name for any Xorg output<p><b>To recap, this is <i>not a TDE shortcoming</i>, but rather is the result of a lack of fundamental Linux support for graphics configuration!</b></qt>");
+			base->labelRandrWarning->setText(i18n("<qt><b>NOTE: Any further integration of displays into TDE <i>REQUIRES</i> multi GPU support and other features slated for RandR 2.0.</b><p>Development on such features has been sorely lacking for well over a year as of 2012; if you want to see Linux come up to Windows and Macintosh standards in this area <i>please tell the Xorg developers</i> at http://www.x.org/wiki/XorgMailingLists<p>The TDE project badly needs these features before it can proceed with graphical monitor configuration tools:<br> * GPU object support<br> * The ability to query the active driver name for any Xorg output<p><b>To recap, this is <i>not a TDE shortcoming</i>, but rather is the result of a lack of fundamental Linux support for graphics configuration!</b></qt>"));
 		}
 
 		if (m_device->type() == TDEGenericDeviceType::RootSystem) {
